aboutsummaryrefslogtreecommitdiffstats
path: root/native/jni/src
diff options
context:
space:
mode:
Diffstat (limited to 'native/jni/src')
-rw-r--r--native/jni/src/defines.h4
1 files changed, 3 insertions, 1 deletions
diff --git a/native/jni/src/defines.h b/native/jni/src/defines.h
index 28fe1fe37..a84dfddec 100644
--- a/native/jni/src/defines.h
+++ b/native/jni/src/defines.h
@@ -398,8 +398,10 @@ typedef enum {
EQUIVALENT_CHAR,
// It is a char located nearby on the keyboard
NEAR_PROXIMITY_CHAR,
// It is an unrelated char
UNRELATED_CHAR,
+ // It is an unrelated char nor a substitution char
+ UNRELATED_NOR_SUBSTITUTION_CHAR,
// Additional proximity char which can differ by language.
ADDITIONAL_PROXIMITY_CHAR
} ProximityType;
@@ -398,8 +398,10 @@ typedef enum {
// It is a char located nearby on the keyboard
NEAR_PROXIMITY_CHAR,
- // It is an unrelated char
+ // It is an unrelated char and could be a substitution char
UNRELATED_CHAR,